@@ -1,7 +1,11 @@
-use std::process;
+use std::{process, time::Duration};
 
 use wethr::{
-    args, location::client::LocationClient, spinner::Spinner, weather::client::WeatherClient,
+    args,
+    client::{CLIENT_CONNECT_TIMEOUT, CLIENT_TIMEOUT},
+    location::client::LocationClient,
+    spinner::Spinner,
+    weather::client::WeatherClient,
 };
 
 #[tokio::main(flavor = "current_thread")]
@@ -12,15 +16,27 @@ async fn main() -> anyhow::Result<()> {
         process::exit(0);
     }
     let spinner = Spinner::new();
+    let connect_timeout = opts.connect_timeout.unwrap_or(CLIENT_CONNECT_TIMEOUT);
+    let timeout = opts.timeout.unwrap_or(CLIENT_TIMEOUT);
     let location = spinner
         .set_message("Detecting your location")
-        .run(LocationClient::new().get())
+        .run(
+            LocationClient::new()
+                .set_connect_timeout(Duration::from_secs(connect_timeout))
+                .set_timeout(Duration::from_secs(timeout))
+                .get(),
+        )
         .await?;
     let units = opts.units.unwrap_or_default();
     let weather = spinner
         .set_color("yellow")
         .set_message("Loading weather")
-        .run(WeatherClient::new().get_with_units(&location.coordinates, units))
+        .run(
+            WeatherClient::new()
+                .set_connect_timeout(Duration::from_secs(connect_timeout))
+                .set_timeout(Duration::from_secs(timeout))
+                .get_with_units(&location.coordinates, units),
+        )
         .await?;
     spinner.println(format!(
         "{city}, {country}: {temperature}{units} {emoji}",
